@@ -1,5 +1,5 @@
 """
-Copyright 2019-2022 Trevor James Smith and Ouranos Inc.
+Copyright 2019-2023 Trevor James Smith and Ouranos Inc.
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -16,18 +16,15 @@ limitations under the License.
 
 __author__ = "Trevor James Smith"
 __email__ = "smith.trevorj@ouranos.ca"
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 
-from . import (
+from . import (  # convert,
     archive,
     convert,
     cv,
     decode,
-    eccc,
-    ecmwf,
-    ncar,
-    remote,
+    io,
     scripting,
     structure,
     units,
