@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 import datetime as dt
-import logging
+import logging.config
 import re
 import warnings
 from argparse import ArgumentParser
@@ -20,9 +20,9 @@ from miranda import __version__
 from miranda.scripting import LOGGING_CONFIG
 
 from ._data_corrections import (
+    dataset_corrections,
     load_json_data_mappings,
     metadata_conversion,
-    variable_conversion,
 )
 
 logging.config.dictConfig(LOGGING_CONFIG)
@@ -39,6 +39,18 @@ frequencies = {
     "z": ("4min", "4 min"),  # 4T
 }
 
+__all__ = [
+    "parse_var_code",
+    "list_tables",
+    "read_table",
+    "read_definitions",
+    "read_stations",
+    "convert_mdb",
+    "convert_snow_table",
+    "concat",
+    "convert_melcc_obs",
+]
+
 
 def parse_var_code(vcode):
     match = re.match(r"([^\d]*)(\d*)([abcfhqz])", vcode)
@@ -232,7 +244,7 @@ def convert_mdb(
         else:
             raw = raw.assign_coords(station=stat)
 
-        ds = variable_conversion(raw, "melcc-obs")
+        ds = dataset_corrections(raw, "melcc-obs")
         new_var_name = list(
             filter(lambda k: not k.endswith("_flag"), ds.data_vars.keys())
         )[0]
@@ -336,7 +348,7 @@ def concat(
 
 
 def convert_snow_table(file: str | Path, output: str | Path):
-    """Convert snow data given through an excel file.
+    """Convert snow data given through an Excel file.
 
     This private data is not included in the MDB files.
 
