@@ -17,17 +17,12 @@ import xarray as xr
 import zarr
 from pandas._libs.tslibs import NaTType  # noqa
 
-from miranda.convert.utils import find_version_hash  # noqa
+from miranda.convert.utils import date_parser, find_version_hash  # noqa
 from miranda.cv import VALIDATION_ENABLED
 from miranda.scripting import LOGGING_CONFIG
 from miranda.units import get_time_frequency
 
-from ._time import (
-    TIME_UNITS_TO_FREQUENCY,
-    TIME_UNITS_TO_TIMEDELTA,
-    DecoderError,
-    date_parser,
-)
+from ._time import TIME_UNITS_TO_FREQUENCY, TIME_UNITS_TO_TIMEDELTA, DecoderError
 
 if VALIDATION_ENABLED:
     from miranda.cv import INSTITUTIONS, PROJECT_MODELS
@@ -67,7 +62,6 @@ def guess_project(file: Union[os.PathLike, str]) -> str:
 
 
 class Decoder:
-
     project = None
     guess = False
     _file_facets = dict()
@@ -214,19 +208,19 @@ class Decoder:
         """
         dimsvar_dict = dict()
         coords = (
-            "time",
+            "height",
             "lat",
             "latitude",
+            "lev",
+            "level",
             "lon",
             "longitude",
             "rlat",
             "rlon",
-            "height",
-            "lev",
             "rotated_pole",
+            "time",
         )
         try:
-
             if file.is_file() and file.suffix in [".nc", ".nc4"]:
                 with nc.Dataset(file, mode="r") as ds:
                     for var_name, var_attrs in ds.variables.items():
@@ -325,8 +319,8 @@ class Decoder:
             return pd.to_timedelta(time_dictionary[term])
 
         if data and not file:
-            potential_time = data.get("frequency", "")
-            if potential_time == "":
+            potential_time = data.get("frequency")
+            if not potential_time:
                 if hasattr(data, "time"):
                     time_units = data["time"].units
                     potential_time = time_units.split()[0]
